# pylint: disable=too-many-lines
"""The configuration commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CONFIGuration:ADVMATH?
    - CONFIGuration:AFG?
    - CONFIGuration:ANALOg:BANDWidth?
    - CONFIGuration:ANALOg:GNDCPLG?
    - CONFIGuration:ANALOg:MAXBANDWidth?
    - CONFIGuration:ANALOg:MAXSAMPLERate?
    - CONFIGuration:ANALOg:NUMCHANnels?
    - CONFIGuration:ANALOg:RECLENS?
    - CONFIGuration:ANALOg:VERTINVert?
    - CONFIGuration:APPLications:CUSTOMMask?
    - CONFIGuration:APPLications:LIMITMask?
    - CONFIGuration:APPLications:POWer?
    - CONFIGuration:APPLications:STANDARDMask?
    - CONFIGuration:APPLications:VIDPIC?
    - CONFIGuration:ARB?
    - CONFIGuration:AUXIN?
    - CONFIGuration:BUSWAVEFORMS:ARINC429A?
    - CONFIGuration:BUSWAVEFORMS:AUDIO?
    - CONFIGuration:BUSWAVEFORMS:CAN?
    - CONFIGuration:BUSWAVEFORMS:CANFD?
    - CONFIGuration:BUSWAVEFORMS:ETHERNET?
    - CONFIGuration:BUSWAVEFORMS:FLEXRAY?
    - CONFIGuration:BUSWAVEFORMS:I2C?
    - CONFIGuration:BUSWAVEFORMS:LIN?
    - CONFIGuration:BUSWAVEFORMS:MIL1553B?
    - CONFIGuration:BUSWAVEFORMS:NUMBUS?
    - CONFIGuration:BUSWAVEFORMS:PARallel?
    - CONFIGuration:BUSWAVEFORMS:RS232C?
    - CONFIGuration:BUSWAVEFORMS:SPI?
    - CONFIGuration:BUSWAVEFORMS:USB:HS?
    - CONFIGuration:BUSWAVEFORMS:USB?
    - CONFIGuration:DIGITAl:MAGnivu?
    - CONFIGuration:DIGITAl:MAXSAMPLERate?
    - CONFIGuration:DIGITAl:NUMCHANnels?
    - CONFIGuration:DVM?
    - CONFIGuration:EXTVIDEO?
    - CONFIGuration:HISTOGRAM?
    - CONFIGuration:NETWORKDRIVES?
    - CONFIGuration:NUMMEAS?
    - CONFIGuration:REFS:NUMREFS?
    - CONFIGuration:RF:ADVTRIG?
    - CONFIGuration:RF:BANDWidth?
    - CONFIGuration:RF:MAXBANDWidth?
    - CONFIGuration:RF:NUMCHANnels?
    - CONFIGuration:ROSC?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ConfigurationRosc(SCPICmdRead):
    """The ``CONFIGuration:ROSC`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the instrument has an external
          reference oscillator (ROSC) input.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ROSC?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ROSC?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ROSC?
    """


class ConfigurationRfNumchannels(SCPICmdRead):
    """The ``CONFIGuration:RF:NUMCHANnels`` command.

    **Description:**
        - This query returns the number of RF channels present. If no RF channels are present, the
          query returns 0. )

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:RF:NUMCHANnels?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:NUMCHANnels?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:RF:NUMCHANnels?
    """


class ConfigurationRfMaxbandwidth(SCPICmdRead):
    """The ``CONFIGuration:RF:MAXBANDWidth`` command.

    **Description:**
        - This query returns the maximum bandwidth, in hertz, for RF channels. If no RF channels are
          present, the query returns 0. Enabling this feature requires an MDO4000/B/C Series
          oscilloscope and installation of a MDO4TRIG option.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:RF:MAXBANDWidth?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:MAXBANDWidth?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:RF:MAXBANDWidth?
    """


class ConfigurationRfBandwidth(SCPICmdRead):
    """The ``CONFIGuration:RF:BANDWidth`` command.

    **Description:**
        - This query returns the bandwidth, in Hz, for the RF channel(s). If there are no RF
          channels, the value returned is 0.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:RF:BANDWidth?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:BANDWidth?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:RF:BANDWidth?
    """


class ConfigurationRfAdvtrig(SCPICmdRead):
    """The ``CONFIGuration:RF:ADVTRIG`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the advanced RF trigger and
          analysis feature is present. (Enabling this feature requires an MDO4000/B/C Series
          oscilloscope and installation of a MDO4TRIG application option.)

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:RF:ADVTRIG?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:ADVTRIG?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:RF:ADVTRIG?
    """


class ConfigurationRf(SCPICmdRead):
    """The ``CONFIGuration:RF`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:RF?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.advtrig``: The ``CONFIGuration:RF:ADVTRIG`` command.
        - ``.bandwidth``: The ``CONFIGuration:RF:BANDWidth`` command.
        - ``.maxbandwidth``: The ``CONFIGuration:RF:MAXBANDWidth`` command.
        - ``.numchannels``: The ``CONFIGuration:RF:NUMCHANnels`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._advtrig = ConfigurationRfAdvtrig(device, f"{self._cmd_syntax}:ADVTRIG")
        self._bandwidth = ConfigurationRfBandwidth(device, f"{self._cmd_syntax}:BANDWidth")
        self._maxbandwidth = ConfigurationRfMaxbandwidth(device, f"{self._cmd_syntax}:MAXBANDWidth")
        self._numchannels = ConfigurationRfNumchannels(device, f"{self._cmd_syntax}:NUMCHANnels")

    @property
    def advtrig(self) -> ConfigurationRfAdvtrig:
        """Return the ``CONFIGuration:RF:ADVTRIG`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the advanced RF trigger and
              analysis feature is present. (Enabling this feature requires an MDO4000/B/C Series
              oscilloscope and installation of a MDO4TRIG application option.)

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:RF:ADVTRIG?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:ADVTRIG?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:RF:ADVTRIG?
        """
        return self._advtrig

    @property
    def bandwidth(self) -> ConfigurationRfBandwidth:
        """Return the ``CONFIGuration:RF:BANDWidth`` command.

        **Description:**
            - This query returns the bandwidth, in Hz, for the RF channel(s). If there are no RF
              channels, the value returned is 0.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:RF:BANDWidth?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:BANDWidth?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:RF:BANDWidth?
        """
        return self._bandwidth

    @property
    def maxbandwidth(self) -> ConfigurationRfMaxbandwidth:
        """Return the ``CONFIGuration:RF:MAXBANDWidth`` command.

        **Description:**
            - This query returns the maximum bandwidth, in hertz, for RF channels. If no RF channels
              are present, the query returns 0. Enabling this feature requires an MDO4000/B/C Series
              oscilloscope and installation of a MDO4TRIG option.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:RF:MAXBANDWidth?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:MAXBANDWidth?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:RF:MAXBANDWidth?
        """
        return self._maxbandwidth

    @property
    def numchannels(self) -> ConfigurationRfNumchannels:
        """Return the ``CONFIGuration:RF:NUMCHANnels`` command.

        **Description:**
            - This query returns the number of RF channels present. If no RF channels are present,
              the query returns 0. )

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:RF:NUMCHANnels?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF:NUMCHANnels?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:RF:NUMCHANnels?
        """
        return self._numchannels


class ConfigurationRefsNumrefs(SCPICmdRead):
    """The ``CONFIGuration:REFS:NUMREFS`` command.

    **Description:**
        - This query returns the number of reference waveforms.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:REFS:NUMREFS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:REFS:NUMREFS?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:REFS:NUMREFS?
    """


class ConfigurationRefs(SCPICmdRead):
    """The ``CONFIGuration:REFS`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:REFS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:REFS?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.numrefs``: The ``CONFIGuration:REFS:NUMREFS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._numrefs = ConfigurationRefsNumrefs(device, f"{self._cmd_syntax}:NUMREFS")

    @property
    def numrefs(self) -> ConfigurationRefsNumrefs:
        """Return the ``CONFIGuration:REFS:NUMREFS`` command.

        **Description:**
            - This query returns the number of reference waveforms.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:REFS:NUMREFS?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:REFS:NUMREFS?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:REFS:NUMREFS?
        """
        return self._numrefs


class ConfigurationNummeas(SCPICmdRead):
    """The ``CONFIGuration:NUMMEAS`` command.

    **Description:**
        - This query returns the maximum number of periodic measurements.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:NUMMEAS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:NUMMEAS?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:NUMMEAS?
    """


class ConfigurationNetworkdrives(SCPICmdRead):
    """The ``CONFIGuration:NETWORKDRIVES`` command.

    **Description:**
        - This query returns a boolean value to indicate whether network drives are supported.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:NETWORKDRIVES?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:NETWORKDRIVES?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:NETWORKDRIVES?
    """


class ConfigurationHistogram(SCPICmdRead):
    """The ``CONFIGuration:HISTOGRAM`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the waveform histogram feature is
          present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:HISTOGRAM?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:HISTOGRAM?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:HISTOGRAM?
    """


class ConfigurationExtvideo(SCPICmdRead):
    """The ``CONFIGuration:EXTVIDEO`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the extended video trigger features
          are present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:EXTVIDEO?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:EXTVIDEO?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:EXTVIDEO?
    """


class ConfigurationDvm(SCPICmdRead):
    """The ``CONFIGuration:DVM`` command.

    **Description:**
        - Indicates whether the Digital Voltmeter hardware is present, and the DVM feature is
          enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:DVM?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:DVM?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:DVM?
    """


class ConfigurationDigitalNumchannels(SCPICmdRead):
    """The ``CONFIGuration:DIGITAl:NUMCHANnels`` command.

    **Description:**
        - This query returns the number of digital channels.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:NUMCHANnels?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl:NUMCHANnels?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:DIGITAl:NUMCHANnels?
    """


class ConfigurationDigitalMaxsamplerate(SCPICmdRead):
    """The ``CONFIGuration:DIGITAl:MAXSAMPLERate`` command.

    **Description:**
        - This query returns the maximum sample rate for digital channels, in samples per second. If
          there are no digital channels, the value returned is 0.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:MAXSAMPLERate?``
          query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl:MAXSAMPLERate?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:DIGITAl:MAXSAMPLERate?
    """


class ConfigurationDigitalMagnivu(SCPICmdRead):
    """The ``CONFIGuration:DIGITAl:MAGnivu`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the instrument supports the MagniVu
          feature for digital channels. If there are no digital channels, the value returned is 0.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:MAGnivu?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl:MAGnivu?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:DIGITAl:MAGnivu?
    """


class ConfigurationDigital(SCPICmdRead):
    """The ``CONFIGuration:DIGITAl`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.magnivu``: The ``CONFIGuration:DIGITAl:MAGnivu`` command.
        - ``.maxsamplerate``: The ``CONFIGuration:DIGITAl:MAXSAMPLERate`` command.
        - ``.numchannels``: The ``CONFIGuration:DIGITAl:NUMCHANnels`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._magnivu = ConfigurationDigitalMagnivu(device, f"{self._cmd_syntax}:MAGnivu")
        self._maxsamplerate = ConfigurationDigitalMaxsamplerate(
            device, f"{self._cmd_syntax}:MAXSAMPLERate"
        )
        self._numchannels = ConfigurationDigitalNumchannels(
            device, f"{self._cmd_syntax}:NUMCHANnels"
        )

    @property
    def magnivu(self) -> ConfigurationDigitalMagnivu:
        """Return the ``CONFIGuration:DIGITAl:MAGnivu`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the instrument supports the
              MagniVu feature for digital channels. If there are no digital channels, the value
              returned is 0.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:MAGnivu?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl:MAGnivu?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:DIGITAl:MAGnivu?
        """
        return self._magnivu

    @property
    def maxsamplerate(self) -> ConfigurationDigitalMaxsamplerate:
        """Return the ``CONFIGuration:DIGITAl:MAXSAMPLERate`` command.

        **Description:**
            - This query returns the maximum sample rate for digital channels, in samples per
              second. If there are no digital channels, the value returned is 0.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:MAXSAMPLERate?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:DIGITAl:MAXSAMPLERate?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:DIGITAl:MAXSAMPLERate?
        """
        return self._maxsamplerate

    @property
    def numchannels(self) -> ConfigurationDigitalNumchannels:
        """Return the ``CONFIGuration:DIGITAl:NUMCHANnels`` command.

        **Description:**
            - This query returns the number of digital channels.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl:NUMCHANnels?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:DIGITAl:NUMCHANnels?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:DIGITAl:NUMCHANnels?
        """
        return self._numchannels


class ConfigurationBuswaveformsUsbHs(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:USB:HS`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the high-speed USB bus triggering
          and analysis feature is present. Depending upon the bandwidth of the instrument, USB bus
          triggering and analysis features may be limited to USB low-speed or full-speed. If the
          instrument bandwidth is sufficient, USB high-speed (HS) triggering and analysis is
          supported as long as the 3-SRUSB2 application option is installed.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB:HS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB:HS?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:USB:HS?
    """


class ConfigurationBuswaveformsUsb(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:USB`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the USB bus triggering and analysis
          feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:USB?

    Properties:
        - ``.hs``: The ``CONFIGuration:BUSWAVEFORMS:USB:HS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._hs = ConfigurationBuswaveformsUsbHs(device, f"{self._cmd_syntax}:HS")

    @property
    def hs(self) -> ConfigurationBuswaveformsUsbHs:
        """Return the ``CONFIGuration:BUSWAVEFORMS:USB:HS`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the high-speed USB bus
              triggering and analysis feature is present. Depending upon the bandwidth of the
              instrument, USB bus triggering and analysis features may be limited to USB low-speed
              or full-speed. If the instrument bandwidth is sufficient, USB high-speed (HS)
              triggering and analysis is supported as long as the 3-SRUSB2 application option is
              installed.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB:HS?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:USB:HS?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:USB:HS?
        """
        return self._hs


class ConfigurationBuswaveformsSpi(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:SPI`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional SPI bus triggering and
          analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:SPI?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:SPI?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:SPI?
    """


class ConfigurationBuswaveformsRs232c(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:RS232C`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional RS232 bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:RS232C?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:RS232C?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:RS232C?
    """


class ConfigurationBuswaveformsParallel(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:PARallel`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the parallel bus triggering and
          analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:PARallel?``
          query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:PARallel?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:PARallel?
    """


class ConfigurationBuswaveformsNumbus(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:NUMBUS`` command.

    **Description:**
        - This query returns the number of bus waveforms.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:NUMBUS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:NUMBUS?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:NUMBUS?
    """


class ConfigurationBuswaveformsMil1553b(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:MIL1553B`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional MIL-STD-1553 bus
          triggering and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:MIL1553B?``
          query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:MIL1553B?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:MIL1553B?
    """


class ConfigurationBuswaveformsLin(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:LIN`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional LIN bus triggering and
          analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:LIN?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:LIN?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:LIN?
    """


class ConfigurationBuswaveformsI2c(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:I2C`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional I 2 C bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:I2C?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:I2C?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:I2C?
    """


class ConfigurationBuswaveformsFlexray(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:FLEXRAY`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional FlexRay bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:FLEXRAY?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:FLEXRAY?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:FLEXRAY?
    """


class ConfigurationBuswaveformsEthernet(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:ETHERNET`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional Ethernet triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:ETHERNET?``
          query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:ETHERNET?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:ETHERNET?
    """


class ConfigurationBuswaveformsCanfd(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:CANFD`` command.

    **Description:**
        - This query returns a Boolean value to indicate whether the optional CAN FD bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:CANFD?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:CANFD?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:CANFD?
    """


class ConfigurationBuswaveformsCan(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:CAN`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional CAN bus triggering and
          analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:CAN?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:CAN?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:CAN?
    """


class ConfigurationBuswaveformsAudio(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:AUDIO`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional audio bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:AUDIO?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:AUDIO?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:AUDIO?
    """


class ConfigurationBuswaveformsArinc429a(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS:ARINC429A`` command.

    **Description:**
        - This query returns a Boolean value to indicate whether the optional CAN-FD bus triggering
          and analysis feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:ARINC429A?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``CONFIGuration:BUSWAVEFORMS:ARINC429A?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:BUSWAVEFORMS:ARINC429A?
    """


#  pylint: disable=too-many-instance-attributes
class ConfigurationBuswaveforms(SCPICmdRead):
    """The ``CONFIGuration:BUSWAVEFORMS`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.arinc429a``: The ``CONFIGuration:BUSWAVEFORMS:ARINC429A`` command.
        - ``.audio``: The ``CONFIGuration:BUSWAVEFORMS:AUDIO`` command.
        - ``.can``: The ``CONFIGuration:BUSWAVEFORMS:CAN`` command.
        - ``.canfd``: The ``CONFIGuration:BUSWAVEFORMS:CANFD`` command.
        - ``.ethernet``: The ``CONFIGuration:BUSWAVEFORMS:ETHERNET`` command.
        - ``.flexray``: The ``CONFIGuration:BUSWAVEFORMS:FLEXRAY`` command.
        - ``.i2c``: The ``CONFIGuration:BUSWAVEFORMS:I2C`` command.
        - ``.lin``: The ``CONFIGuration:BUSWAVEFORMS:LIN`` command.
        - ``.mil1553b``: The ``CONFIGuration:BUSWAVEFORMS:MIL1553B`` command.
        - ``.numbus``: The ``CONFIGuration:BUSWAVEFORMS:NUMBUS`` command.
        - ``.parallel``: The ``CONFIGuration:BUSWAVEFORMS:PARallel`` command.
        - ``.rs232c``: The ``CONFIGuration:BUSWAVEFORMS:RS232C`` command.
        - ``.spi``: The ``CONFIGuration:BUSWAVEFORMS:SPI`` command.
        - ``.usb``: The ``CONFIGuration:BUSWAVEFORMS:USB`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._arinc429a = ConfigurationBuswaveformsArinc429a(
            device, f"{self._cmd_syntax}:ARINC429A"
        )
        self._audio = ConfigurationBuswaveformsAudio(device, f"{self._cmd_syntax}:AUDIO")
        self._can = ConfigurationBuswaveformsCan(device, f"{self._cmd_syntax}:CAN")
        self._canfd = ConfigurationBuswaveformsCanfd(device, f"{self._cmd_syntax}:CANFD")
        self._ethernet = ConfigurationBuswaveformsEthernet(device, f"{self._cmd_syntax}:ETHERNET")
        self._flexray = ConfigurationBuswaveformsFlexray(device, f"{self._cmd_syntax}:FLEXRAY")
        self._i2c = ConfigurationBuswaveformsI2c(device, f"{self._cmd_syntax}:I2C")
        self._lin = ConfigurationBuswaveformsLin(device, f"{self._cmd_syntax}:LIN")
        self._mil1553b = ConfigurationBuswaveformsMil1553b(device, f"{self._cmd_syntax}:MIL1553B")
        self._numbus = ConfigurationBuswaveformsNumbus(device, f"{self._cmd_syntax}:NUMBUS")
        self._parallel = ConfigurationBuswaveformsParallel(device, f"{self._cmd_syntax}:PARallel")
        self._rs232c = ConfigurationBuswaveformsRs232c(device, f"{self._cmd_syntax}:RS232C")
        self._spi = ConfigurationBuswaveformsSpi(device, f"{self._cmd_syntax}:SPI")
        self._usb = ConfigurationBuswaveformsUsb(device, f"{self._cmd_syntax}:USB")

    @property
    def arinc429a(self) -> ConfigurationBuswaveformsArinc429a:
        """Return the ``CONFIGuration:BUSWAVEFORMS:ARINC429A`` command.

        **Description:**
            - This query returns a Boolean value to indicate whether the optional CAN-FD bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:ARINC429A?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:ARINC429A?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:ARINC429A?
        """
        return self._arinc429a

    @property
    def audio(self) -> ConfigurationBuswaveformsAudio:
        """Return the ``CONFIGuration:BUSWAVEFORMS:AUDIO`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional audio bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:AUDIO?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:AUDIO?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:AUDIO?
        """
        return self._audio

    @property
    def can(self) -> ConfigurationBuswaveformsCan:
        """Return the ``CONFIGuration:BUSWAVEFORMS:CAN`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional CAN bus triggering
              and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:CAN?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:CAN?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:CAN?
        """
        return self._can

    @property
    def canfd(self) -> ConfigurationBuswaveformsCanfd:
        """Return the ``CONFIGuration:BUSWAVEFORMS:CANFD`` command.

        **Description:**
            - This query returns a Boolean value to indicate whether the optional CAN FD bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:CANFD?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:CANFD?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:CANFD?
        """
        return self._canfd

    @property
    def ethernet(self) -> ConfigurationBuswaveformsEthernet:
        """Return the ``CONFIGuration:BUSWAVEFORMS:ETHERNET`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional Ethernet
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:ETHERNET?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:ETHERNET?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:ETHERNET?
        """
        return self._ethernet

    @property
    def flexray(self) -> ConfigurationBuswaveformsFlexray:
        """Return the ``CONFIGuration:BUSWAVEFORMS:FLEXRAY`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional FlexRay bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:FLEXRAY?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:FLEXRAY?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:FLEXRAY?
        """
        return self._flexray

    @property
    def i2c(self) -> ConfigurationBuswaveformsI2c:
        """Return the ``CONFIGuration:BUSWAVEFORMS:I2C`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional I 2 C bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:I2C?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:I2C?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:I2C?
        """
        return self._i2c

    @property
    def lin(self) -> ConfigurationBuswaveformsLin:
        """Return the ``CONFIGuration:BUSWAVEFORMS:LIN`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional LIN bus triggering
              and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:LIN?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:LIN?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:LIN?
        """
        return self._lin

    @property
    def mil1553b(self) -> ConfigurationBuswaveformsMil1553b:
        """Return the ``CONFIGuration:BUSWAVEFORMS:MIL1553B`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional MIL-STD-1553 bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:MIL1553B?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:MIL1553B?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:MIL1553B?
        """
        return self._mil1553b

    @property
    def numbus(self) -> ConfigurationBuswaveformsNumbus:
        """Return the ``CONFIGuration:BUSWAVEFORMS:NUMBUS`` command.

        **Description:**
            - This query returns the number of bus waveforms.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:NUMBUS?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:NUMBUS?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:NUMBUS?
        """
        return self._numbus

    @property
    def parallel(self) -> ConfigurationBuswaveformsParallel:
        """Return the ``CONFIGuration:BUSWAVEFORMS:PARallel`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the parallel bus triggering and
              analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:PARallel?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:PARallel?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:PARallel?
        """
        return self._parallel

    @property
    def rs232c(self) -> ConfigurationBuswaveformsRs232c:
        """Return the ``CONFIGuration:BUSWAVEFORMS:RS232C`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional RS232 bus
              triggering and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:RS232C?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:BUSWAVEFORMS:RS232C?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:RS232C?
        """
        return self._rs232c

    @property
    def spi(self) -> ConfigurationBuswaveformsSpi:
        """Return the ``CONFIGuration:BUSWAVEFORMS:SPI`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional SPI bus triggering
              and analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:SPI?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:SPI?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:SPI?
        """
        return self._spi

    @property
    def usb(self) -> ConfigurationBuswaveformsUsb:
        """Return the ``CONFIGuration:BUSWAVEFORMS:USB`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the USB bus triggering and
              analysis feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS:USB?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:BUSWAVEFORMS:USB?

        Sub-properties:
            - ``.hs``: The ``CONFIGuration:BUSWAVEFORMS:USB:HS`` command.
        """
        return self._usb


class ConfigurationAuxin(SCPICmdRead):
    """The ``CONFIGuration:AUXIN`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the instrument has an Aux Input
          connector.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:AUXIN?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:AUXIN?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:AUXIN?
    """


class ConfigurationArb(SCPICmdRead):
    """The ``CONFIGuration:ARB`` command.

    **Description:**
        - Indicates whether or not the arbitrary function generator hardware is present, and the
          user-defined arbitrary waveform generation feature is enabled. Note that this is different
          than the ``CONFIGuration:AFG?`` query. The ability to generate arbitrary waveforms is an
          extension of the standard AFG features.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ARB?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ARB?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ARB?
    """


class ConfigurationApplicationsVidpic(SCPICmdRead):
    """The ``CONFIGuration:APPLications:VIDPIC`` command.

    **Description:**
        - Indicates whether the Video Picture feature is present and enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:VIDPIC?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:APPLications:VIDPIC?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:APPLications:VIDPIC?
    """


class ConfigurationApplicationsStandardmask(SCPICmdRead):
    """The ``CONFIGuration:APPLications:STANDARDMask`` command.

    **Description:**
        - Indicates whether the Standard Mask test feature is present and enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:STANDARDMask?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``CONFIGuration:APPLications:STANDARDMask?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:APPLications:STANDARDMask?
    """


class ConfigurationApplicationsPower(SCPICmdRead):
    """The ``CONFIGuration:APPLications:POWer`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional power application
          feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:POWer?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:APPLications:POWer?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:APPLications:POWer?
    """


class ConfigurationApplicationsLimitmask(SCPICmdRead):
    """The ``CONFIGuration:APPLications:LIMITMask`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the optional mask/limit test
          feature is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:LIMITMask?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``CONFIGuration:APPLications:LIMITMask?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:APPLications:LIMITMask?
    """


class ConfigurationApplicationsCustommask(SCPICmdRead):
    """The ``CONFIGuration:APPLications:CUSTOMMask`` command.

    **Description:**
        - Indicates whether the Custom Mask test feature is present and enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:CUSTOMMask?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``CONFIGuration:APPLications:CUSTOMMask?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:APPLications:CUSTOMMask?
    """


class ConfigurationApplications(SCPICmdRead):
    """The ``CONFIGuration:APPLications`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:APPLications?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:APPLications?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.custommask``: The ``CONFIGuration:APPLications:CUSTOMMask`` command.
        - ``.limitmask``: The ``CONFIGuration:APPLications:LIMITMask`` command.
        - ``.power``: The ``CONFIGuration:APPLications:POWer`` command.
        - ``.standardmask``: The ``CONFIGuration:APPLications:STANDARDMask`` command.
        - ``.vidpic``: The ``CONFIGuration:APPLications:VIDPIC`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._custommask = ConfigurationApplicationsCustommask(
            device, f"{self._cmd_syntax}:CUSTOMMask"
        )
        self._limitmask = ConfigurationApplicationsLimitmask(
            device, f"{self._cmd_syntax}:LIMITMask"
        )
        self._power = ConfigurationApplicationsPower(device, f"{self._cmd_syntax}:POWer")
        self._standardmask = ConfigurationApplicationsStandardmask(
            device, f"{self._cmd_syntax}:STANDARDMask"
        )
        self._vidpic = ConfigurationApplicationsVidpic(device, f"{self._cmd_syntax}:VIDPIC")

    @property
    def custommask(self) -> ConfigurationApplicationsCustommask:
        """Return the ``CONFIGuration:APPLications:CUSTOMMask`` command.

        **Description:**
            - Indicates whether the Custom Mask test feature is present and enabled.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:CUSTOMMask?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:APPLications:CUSTOMMask?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:APPLications:CUSTOMMask?
        """
        return self._custommask

    @property
    def limitmask(self) -> ConfigurationApplicationsLimitmask:
        """Return the ``CONFIGuration:APPLications:LIMITMask`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional mask/limit test
              feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:LIMITMask?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:APPLications:LIMITMask?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:APPLications:LIMITMask?
        """
        return self._limitmask

    @property
    def power(self) -> ConfigurationApplicationsPower:
        """Return the ``CONFIGuration:APPLications:POWer`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the optional power application
              feature is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:POWer?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:APPLications:POWer?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:APPLications:POWer?
        """
        return self._power

    @property
    def standardmask(self) -> ConfigurationApplicationsStandardmask:
        """Return the ``CONFIGuration:APPLications:STANDARDMask`` command.

        **Description:**
            - Indicates whether the Standard Mask test feature is present and enabled.

        **Usage:**
            - Using the ``.query()`` method will send the
              ``CONFIGuration:APPLications:STANDARDMask?`` query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:APPLications:STANDARDMask?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:APPLications:STANDARDMask?
        """
        return self._standardmask

    @property
    def vidpic(self) -> ConfigurationApplicationsVidpic:
        """Return the ``CONFIGuration:APPLications:VIDPIC`` command.

        **Description:**
            - Indicates whether the Video Picture feature is present and enabled.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:APPLications:VIDPIC?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:APPLications:VIDPIC?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:APPLications:VIDPIC?
        """
        return self._vidpic


class ConfigurationAnalogVertinvert(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:VERTINVert`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the vertical invert feature for
          analog channels is present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:VERTINVert?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:VERTINVert?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:VERTINVert?
    """


class ConfigurationAnalogReclens(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:RECLENS`` command.

    **Description:**
        - This query returns a comma-separated list of supported record lengths for the analog
          channels.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:RECLENS?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:RECLENS?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:RECLENS?
    """


class ConfigurationAnalogNumchannels(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:NUMCHANnels`` command.

    **Description:**
        - This query returns the number of analog channels.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:NUMCHANnels?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:NUMCHANnels?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:NUMCHANnels?
    """


class ConfigurationAnalogMaxsamplerate(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:MAXSAMPLERate`` command.

    **Description:**
        - This query returns the maximum sample rate for analog channels.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:MAXSAMPLERate?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:MAXSAMPLERate?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:MAXSAMPLERate?
    """


class ConfigurationAnalogMaxbandwidth(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:MAXBANDWidth`` command.

    **Description:**
        - This query returns the maximum bandwidth for analog channels.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:MAXBANDWidth?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:MAXBANDWidth?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:MAXBANDWidth?
    """


class ConfigurationAnalogGndcplg(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:GNDCPLG`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the ground coupling feature for
          analog channels is present. As this feature is not supported on MSO/DPO4000B, MDO4000/B/C
          or MDO3000 models, this query always returns 0.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:GNDCPLG?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:GNDCPLG?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:GNDCPLG?
    """


class ConfigurationAnalogBandwidth(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:BANDWidth`` command.

    **Description:**
        - This command queries the maximum licensed bandwidth of the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:BANDWidth?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:BANDWidth?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:BANDWidth?
    """


class ConfigurationAnalog(SCPICmdRead):
    """The ``CONFIGuration:ANALOg`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.bandwidth``: The ``CONFIGuration:ANALOg:BANDWidth`` command.
        - ``.gndcplg``: The ``CONFIGuration:ANALOg:GNDCPLG`` command.
        - ``.maxbandwidth``: The ``CONFIGuration:ANALOg:MAXBANDWidth`` command.
        - ``.maxsamplerate``: The ``CONFIGuration:ANALOg:MAXSAMPLERate`` command.
        - ``.numchannels``: The ``CONFIGuration:ANALOg:NUMCHANnels`` command.
        - ``.reclens``: The ``CONFIGuration:ANALOg:RECLENS`` command.
        - ``.vertinvert``: The ``CONFIGuration:ANALOg:VERTINVert`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._bandwidth = ConfigurationAnalogBandwidth(device, f"{self._cmd_syntax}:BANDWidth")
        self._gndcplg = ConfigurationAnalogGndcplg(device, f"{self._cmd_syntax}:GNDCPLG")
        self._maxbandwidth = ConfigurationAnalogMaxbandwidth(
            device, f"{self._cmd_syntax}:MAXBANDWidth"
        )
        self._maxsamplerate = ConfigurationAnalogMaxsamplerate(
            device, f"{self._cmd_syntax}:MAXSAMPLERate"
        )
        self._numchannels = ConfigurationAnalogNumchannels(
            device, f"{self._cmd_syntax}:NUMCHANnels"
        )
        self._reclens = ConfigurationAnalogReclens(device, f"{self._cmd_syntax}:RECLENS")
        self._vertinvert = ConfigurationAnalogVertinvert(device, f"{self._cmd_syntax}:VERTINVert")

    @property
    def bandwidth(self) -> ConfigurationAnalogBandwidth:
        """Return the ``CONFIGuration:ANALOg:BANDWidth`` command.

        **Description:**
            - This command queries the maximum licensed bandwidth of the instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:BANDWidth?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:BANDWidth?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:BANDWidth?
        """
        return self._bandwidth

    @property
    def gndcplg(self) -> ConfigurationAnalogGndcplg:
        """Return the ``CONFIGuration:ANALOg:GNDCPLG`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the ground coupling feature for
              analog channels is present. As this feature is not supported on MSO/DPO4000B,
              MDO4000/B/C or MDO3000 models, this query always returns 0.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:GNDCPLG?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:GNDCPLG?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:GNDCPLG?
        """
        return self._gndcplg

    @property
    def maxbandwidth(self) -> ConfigurationAnalogMaxbandwidth:
        """Return the ``CONFIGuration:ANALOg:MAXBANDWidth`` command.

        **Description:**
            - This query returns the maximum bandwidth for analog channels.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:MAXBANDWidth?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:ANALOg:MAXBANDWidth?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:MAXBANDWidth?
        """
        return self._maxbandwidth

    @property
    def maxsamplerate(self) -> ConfigurationAnalogMaxsamplerate:
        """Return the ``CONFIGuration:ANALOg:MAXSAMPLERate`` command.

        **Description:**
            - This query returns the maximum sample rate for analog channels.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:MAXSAMPLERate?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:ANALOg:MAXSAMPLERate?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:MAXSAMPLERate?
        """
        return self._maxsamplerate

    @property
    def numchannels(self) -> ConfigurationAnalogNumchannels:
        """Return the ``CONFIGuration:ANALOg:NUMCHANnels`` command.

        **Description:**
            - This query returns the number of analog channels.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:NUMCHANnels?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``CONFIGuration:ANALOg:NUMCHANnels?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:NUMCHANnels?
        """
        return self._numchannels

    @property
    def reclens(self) -> ConfigurationAnalogReclens:
        """Return the ``CONFIGuration:ANALOg:RECLENS`` command.

        **Description:**
            - This query returns a comma-separated list of supported record lengths for the analog
              channels.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:RECLENS?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:RECLENS?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:RECLENS?
        """
        return self._reclens

    @property
    def vertinvert(self) -> ConfigurationAnalogVertinvert:
        """Return the ``CONFIGuration:ANALOg:VERTINVert`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the vertical invert feature for
              analog channels is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:VERTINVert?``
              query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:VERTINVert?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:VERTINVert?
        """
        return self._vertinvert


class ConfigurationAfg(SCPICmdRead):
    """The ``CONFIGuration:AFG`` command.

    **Description:**
        - Indicates whether or not the arbitrary function generator hardware is present, and the
          arbitrary function generation feature is enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:AFG?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:AFG?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:AFG?
    """


class ConfigurationAdvmath(SCPICmdRead):
    """The ``CONFIGuration:ADVMATH`` command.

    **Description:**
        - This query returns a boolean value to indicate whether the advanced math feature is
          present.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ADVMATH?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ADVMATH?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ADVMATH?
    """


#  pylint: disable=too-many-instance-attributes
class Configuration(SCPICmdRead):
    """The ``CONFIGuration`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.advmath``: The ``CONFIGuration:ADVMATH`` command.
        - ``.afg``: The ``CONFIGuration:AFG`` command.
        - ``.analog``: The ``CONFIGuration:ANALOg`` command tree.
        - ``.applications``: The ``CONFIGuration:APPLications`` command tree.
        - ``.arb``: The ``CONFIGuration:ARB`` command.
        - ``.auxin``: The ``CONFIGuration:AUXIN`` command.
        - ``.buswaveforms``: The ``CONFIGuration:BUSWAVEFORMS`` command tree.
        - ``.digital``: The ``CONFIGuration:DIGITAl`` command tree.
        - ``.dvm``: The ``CONFIGuration:DVM`` command.
        - ``.extvideo``: The ``CONFIGuration:EXTVIDEO`` command.
        - ``.histogram``: The ``CONFIGuration:HISTOGRAM`` command.
        - ``.networkdrives``: The ``CONFIGuration:NETWORKDRIVES`` command.
        - ``.nummeas``: The ``CONFIGuration:NUMMEAS`` command.
        - ``.refs``: The ``CONFIGuration:REFS`` command tree.
        - ``.rf``: The ``CONFIGuration:RF`` command tree.
        - ``.rosc``: The ``CONFIGuration:ROSC`` command.
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CONFIGuration"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._advmath = ConfigurationAdvmath(device, f"{self._cmd_syntax}:ADVMATH")
        self._afg = ConfigurationAfg(device, f"{self._cmd_syntax}:AFG")
        self._analog = ConfigurationAnalog(device, f"{self._cmd_syntax}:ANALOg")
        self._applications = ConfigurationApplications(device, f"{self._cmd_syntax}:APPLications")
        self._arb = ConfigurationArb(device, f"{self._cmd_syntax}:ARB")
        self._auxin = ConfigurationAuxin(device, f"{self._cmd_syntax}:AUXIN")
        self._buswaveforms = ConfigurationBuswaveforms(device, f"{self._cmd_syntax}:BUSWAVEFORMS")
        self._digital = ConfigurationDigital(device, f"{self._cmd_syntax}:DIGITAl")
        self._dvm = ConfigurationDvm(device, f"{self._cmd_syntax}:DVM")
        self._extvideo = ConfigurationExtvideo(device, f"{self._cmd_syntax}:EXTVIDEO")
        self._histogram = ConfigurationHistogram(device, f"{self._cmd_syntax}:HISTOGRAM")
        self._networkdrives = ConfigurationNetworkdrives(
            device, f"{self._cmd_syntax}:NETWORKDRIVES"
        )
        self._nummeas = ConfigurationNummeas(device, f"{self._cmd_syntax}:NUMMEAS")
        self._refs = ConfigurationRefs(device, f"{self._cmd_syntax}:REFS")
        self._rf = ConfigurationRf(device, f"{self._cmd_syntax}:RF")
        self._rosc = ConfigurationRosc(device, f"{self._cmd_syntax}:ROSC")

    @property
    def advmath(self) -> ConfigurationAdvmath:
        """Return the ``CONFIGuration:ADVMATH`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the advanced math feature is
              present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ADVMATH?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ADVMATH?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ADVMATH?
        """
        return self._advmath

    @property
    def afg(self) -> ConfigurationAfg:
        """Return the ``CONFIGuration:AFG`` command.

        **Description:**
            - Indicates whether or not the arbitrary function generator hardware is present, and the
              arbitrary function generation feature is enabled.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:AFG?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:AFG?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:AFG?
        """
        return self._afg

    @property
    def analog(self) -> ConfigurationAnalog:
        """Return the ``CONFIGuration:ANALOg`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.bandwidth``: The ``CONFIGuration:ANALOg:BANDWidth`` command.
            - ``.gndcplg``: The ``CONFIGuration:ANALOg:GNDCPLG`` command.
            - ``.maxbandwidth``: The ``CONFIGuration:ANALOg:MAXBANDWidth`` command.
            - ``.maxsamplerate``: The ``CONFIGuration:ANALOg:MAXSAMPLERate`` command.
            - ``.numchannels``: The ``CONFIGuration:ANALOg:NUMCHANnels`` command.
            - ``.reclens``: The ``CONFIGuration:ANALOg:RECLENS`` command.
            - ``.vertinvert``: The ``CONFIGuration:ANALOg:VERTINVert`` command.
        """
        return self._analog

    @property
    def applications(self) -> ConfigurationApplications:
        """Return the ``CONFIGuration:APPLications`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:APPLications?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:APPLications?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.custommask``: The ``CONFIGuration:APPLications:CUSTOMMask`` command.
            - ``.limitmask``: The ``CONFIGuration:APPLications:LIMITMask`` command.
            - ``.power``: The ``CONFIGuration:APPLications:POWer`` command.
            - ``.standardmask``: The ``CONFIGuration:APPLications:STANDARDMask`` command.
            - ``.vidpic``: The ``CONFIGuration:APPLications:VIDPIC`` command.
        """
        return self._applications

    @property
    def arb(self) -> ConfigurationArb:
        """Return the ``CONFIGuration:ARB`` command.

        **Description:**
            - Indicates whether or not the arbitrary function generator hardware is present, and the
              user-defined arbitrary waveform generation feature is enabled. Note that this is
              different than the ``CONFIGuration:AFG?`` query. The ability to generate arbitrary
              waveforms is an extension of the standard AFG features.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ARB?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ARB?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ARB?
        """
        return self._arb

    @property
    def auxin(self) -> ConfigurationAuxin:
        """Return the ``CONFIGuration:AUXIN`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the instrument has an Aux Input
              connector.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:AUXIN?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:AUXIN?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:AUXIN?
        """
        return self._auxin

    @property
    def buswaveforms(self) -> ConfigurationBuswaveforms:
        """Return the ``CONFIGuration:BUSWAVEFORMS`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:BUSWAVEFORMS?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:BUSWAVEFORMS?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.arinc429a``: The ``CONFIGuration:BUSWAVEFORMS:ARINC429A`` command.
            - ``.audio``: The ``CONFIGuration:BUSWAVEFORMS:AUDIO`` command.
            - ``.can``: The ``CONFIGuration:BUSWAVEFORMS:CAN`` command.
            - ``.canfd``: The ``CONFIGuration:BUSWAVEFORMS:CANFD`` command.
            - ``.ethernet``: The ``CONFIGuration:BUSWAVEFORMS:ETHERNET`` command.
            - ``.flexray``: The ``CONFIGuration:BUSWAVEFORMS:FLEXRAY`` command.
            - ``.i2c``: The ``CONFIGuration:BUSWAVEFORMS:I2C`` command.
            - ``.lin``: The ``CONFIGuration:BUSWAVEFORMS:LIN`` command.
            - ``.mil1553b``: The ``CONFIGuration:BUSWAVEFORMS:MIL1553B`` command.
            - ``.numbus``: The ``CONFIGuration:BUSWAVEFORMS:NUMBUS`` command.
            - ``.parallel``: The ``CONFIGuration:BUSWAVEFORMS:PARallel`` command.
            - ``.rs232c``: The ``CONFIGuration:BUSWAVEFORMS:RS232C`` command.
            - ``.spi``: The ``CONFIGuration:BUSWAVEFORMS:SPI`` command.
            - ``.usb``: The ``CONFIGuration:BUSWAVEFORMS:USB`` command.
        """
        return self._buswaveforms

    @property
    def digital(self) -> ConfigurationDigital:
        """Return the ``CONFIGuration:DIGITAl`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:DIGITAl?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:DIGITAl?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.magnivu``: The ``CONFIGuration:DIGITAl:MAGnivu`` command.
            - ``.maxsamplerate``: The ``CONFIGuration:DIGITAl:MAXSAMPLERate`` command.
            - ``.numchannels``: The ``CONFIGuration:DIGITAl:NUMCHANnels`` command.
        """
        return self._digital

    @property
    def dvm(self) -> ConfigurationDvm:
        """Return the ``CONFIGuration:DVM`` command.

        **Description:**
            - Indicates whether the Digital Voltmeter hardware is present, and the DVM feature is
              enabled.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:DVM?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:DVM?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:DVM?
        """
        return self._dvm

    @property
    def extvideo(self) -> ConfigurationExtvideo:
        """Return the ``CONFIGuration:EXTVIDEO`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the extended video trigger
              features are present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:EXTVIDEO?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:EXTVIDEO?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:EXTVIDEO?
        """
        return self._extvideo

    @property
    def histogram(self) -> ConfigurationHistogram:
        """Return the ``CONFIGuration:HISTOGRAM`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the waveform histogram feature
              is present.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:HISTOGRAM?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:HISTOGRAM?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:HISTOGRAM?
        """
        return self._histogram

    @property
    def networkdrives(self) -> ConfigurationNetworkdrives:
        """Return the ``CONFIGuration:NETWORKDRIVES`` command.

        **Description:**
            - This query returns a boolean value to indicate whether network drives are supported.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:NETWORKDRIVES?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:NETWORKDRIVES?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:NETWORKDRIVES?
        """
        return self._networkdrives

    @property
    def nummeas(self) -> ConfigurationNummeas:
        """Return the ``CONFIGuration:NUMMEAS`` command.

        **Description:**
            - This query returns the maximum number of periodic measurements.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:NUMMEAS?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:NUMMEAS?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:NUMMEAS?
        """
        return self._nummeas

    @property
    def refs(self) -> ConfigurationRefs:
        """Return the ``CONFIGuration:REFS`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:REFS?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:REFS?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.numrefs``: The ``CONFIGuration:REFS:NUMREFS`` command.
        """
        return self._refs

    @property
    def rf(self) -> ConfigurationRf:
        """Return the ``CONFIGuration:RF`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:RF?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:RF?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.advtrig``: The ``CONFIGuration:RF:ADVTRIG`` command.
            - ``.bandwidth``: The ``CONFIGuration:RF:BANDWidth`` command.
            - ``.maxbandwidth``: The ``CONFIGuration:RF:MAXBANDWidth`` command.
            - ``.numchannels``: The ``CONFIGuration:RF:NUMCHANnels`` command.
        """
        return self._rf

    @property
    def rosc(self) -> ConfigurationRosc:
        """Return the ``CONFIGuration:ROSC`` command.

        **Description:**
            - This query returns a boolean value to indicate whether the instrument has an external
              reference oscillator (ROSC) input.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ROSC?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ROSC?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ROSC?
        """
        return self._rosc



"""TEKSCOPESW device driver module."""
from functools import cached_property
from typing import Any

import pyvisa as visa

from tm_devices.drivers.pi.scopes.tekscope.tekscope import TekScope
from tm_devices.helpers import DeviceConfigEntry


class TekScopeSW(TekScope):
    """TEKSCOPESW device driver."""

    ################################################################################################
    # Magic Methods
    ################################################################################################
    def __init__(
        self,
        config_entry: DeviceConfigEntry,
        verbose: bool,
        visa_resource: visa.resources.MessageBasedResource,
    ) -> None:
        """Create a TekScope device.

        Args:
            config_entry: A config entry object parsed by the DMConfigParser.
            verbose: A boolean indicating if verbose output should be printed.
            visa_resource: The VISA resource object.
        """
        super().__init__(config_entry, verbose, visa_resource)

        # TODO: Remove once auto-generated commands are available for TekScopeSW
        self._commands: Any = NotImplemented
        self._command_argument_constants: Any = NotImplemented

    ################################################################################################
    # Properties
    ################################################################################################
    # TODO: Remove once auto-generated commands are available for TekScopeSW
    @property
    def command_argument_constants(self) -> Any:
        """Return the device command argument constants."""
        return self._command_argument_constants

    # TODO: Remove once auto-generated commands are available for TekScopeSW
    @property
    def commands(self) -> Any:
        """Return the device commands."""
        return self._commands

    @cached_property
    def total_channels(self) -> int:
        """Return the total number of channels (all types)."""
        return 0

    ################################################################################################
    # Private Methods
    ################################################################################################
    def _reboot(self) -> None:
        """Reboot the device."""
        # TODO: overwrite the reboot code here



"""TekScope3k4k package init file."""
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.dpo4k import DPO4K
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.dpo4kb import DPO4KB
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mdo3 import MDO3
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mdo3k import MDO3K
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mdo4k import MDO4K
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mdo4kb import MDO4KB
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mdo4kc import MDO4KC
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mso4k import MSO4K
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.mso4kb import MSO4KB
from tm_devices.drivers.pi.scopes.tekscope_3k_4k.tekscope_3k_4k import TekScope3k4k

__all__ = [
    "MDO3",
    "MDO3K",
    "MDO4K",
    "MDO4KB",
    "MDO4KC",
    "MSO4K",
    "MSO4KB",
    "DPO4K",
    "DPO4KB",
    "TekScope3k4k",
]



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The localnode commands module.

These commands are used in the following models:
SMU2601B, SMU2602B, SMU2604B, SMU2611B, SMU2612B, SMU2614B, SMU2634B, SMU2635B, SMU2636B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - localnode.autolinefreq
    - localnode.description
    - localnode.license
    - localnode.linefreq
    - localnode.model
    - localnode.password
    - localnode.passwordmode
    - localnode.prompts
    - localnode.prompts4882
    - localnode.reset()
    - localnode.revision
    - localnode.serialno
    - localnode.showerrors
"""
from typing import Optional, TYPE_CHECKING, Union

from .._helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class Localnode(BaseTSPCmd):
    """The ``localnode`` command tree.

    Constants:
        - ``.PASSWORD_ALL``: Use passwords on the web interface and all remote command interfaces.
        - ``.PASSWORD_LAN``: Use passwords on the web interface and all LAN interfaces.
        - ``.PASSWORD_NONE``: Disable passwords everywhere.
        - ``.PASSWORD_WEB``: Use passwords on the web interface only.

    Properties/methods:
        - ``.autolinefreq``: The ``localnode.autolinefreq`` attribute.
        - ``.description``: The ``localnode.description`` attribute.
        - ``.license``: The ``localnode.license`` attribute.
        - ``.linefreq``: The ``localnode.linefreq`` attribute.
        - ``.model``: The ``localnode.model`` attribute.
        - ``.password``: The ``localnode.password`` attribute.
        - ``.passwordmode``: The ``localnode.passwordmode`` attribute.
        - ``.prompts``: The ``localnode.prompts`` attribute.
        - ``.prompts4882``: The ``localnode.prompts4882`` attribute.
        - ``.reset()``: The ``localnode.reset()`` function.
        - ``.revision``: The ``localnode.revision`` attribute.
        - ``.serialno``: The ``localnode.serialno`` attribute.
        - ``.showerrors``: The ``localnode.showerrors`` attribute.
    """

    PASSWORD_ALL = "localnode.PASSWORD_ALL"
    """str: Use passwords on the web interface and all remote command interfaces."""
    PASSWORD_LAN = "localnode.PASSWORD_LAN"
    """str: Use passwords on the web interface and all LAN interfaces."""
    PASSWORD_NONE = "localnode.PASSWORD_NONE"
    """str: Disable passwords everywhere."""
    PASSWORD_WEB = "localnode.PASSWORD_WEB"
    """str: Use passwords on the web interface only."""

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "localnode") -> None:
        super().__init__(device, cmd_syntax)

    @property
    def autolinefreq(self) -> str:
        """Access the ``localnode.autolinefreq`` attribute.

        **Description:**
            - This attribute enables or disables automatic power line frequency detection at
              start-up.

        **Usage:**
            - Accessing this property will send the ``print(localnode.autolinefreq)`` query.
            - Setting this property to a value will send the ``localnode.autolinefreq = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.autolinefreq = value
            - print(localnode.autolinefreq)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".autolinefreq"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.autolinefreq)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.autolinefreq`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @autolinefreq.setter
    def autolinefreq(self, value: Union[str, float]) -> None:
        """Access the ``localnode.autolinefreq`` attribute.

        **Description:**
            - This attribute enables or disables automatic power line frequency detection at
              start-up.

        **Usage:**
            - Accessing this property will send the ``print(localnode.autolinefreq)`` query.
            - Setting this property to a value will send the ``localnode.autolinefreq = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.autolinefreq = value
            - print(localnode.autolinefreq)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".autolinefreq", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.autolinefreq = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.autolinefreq`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def description(self) -> str:
        """Access the ``localnode.description`` attribute.

        **Description:**
            - This attribute stores a user-defined description and mDNS service name of the
              instrument.

        **Usage:**
            - Accessing this property will send the ``print(localnode.description)`` query.
            - Setting this property to a value will send the ``localnode.description = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.description = value
            - print(localnode.description)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".description"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.description)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.description`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @description.setter
    def description(self, value: Union[str, float]) -> None:
        """Access the ``localnode.description`` attribute.

        **Description:**
            - This attribute stores a user-defined description and mDNS service name of the
              instrument.

        **Usage:**
            - Accessing this property will send the ``print(localnode.description)`` query.
            - Setting this property to a value will send the ``localnode.description = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.description = value
            - print(localnode.description)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".description", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.description = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.description`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def license(self) -> str:
        """Access the ``localnode.license`` attribute.

        **Description:**
            - This attribute returns the product license agreements.

        **Usage:**
            - Accessing this property will send the ``print(localnode.license)`` query.

        **TSP Syntax:**

        ::

            - print(localnode.license)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".license"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.license)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.license`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def linefreq(self) -> str:
        """Access the ``localnode.linefreq`` attribute.

        **Description:**
            - This attribute contains the power line frequency setting that is used for NPLC
              calculations.

        **Usage:**
            - Accessing this property will send the ``print(localnode.linefreq)`` query.
            - Setting this property to a value will send the ``localnode.linefreq = value`` command.

        **TSP Syntax:**

        ::

            - localnode.linefreq = value
            - print(localnode.linefreq)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".linefreq"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.linefreq)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.linefreq`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @linefreq.setter
    def linefreq(self, value: Union[str, float]) -> None:
        """Access the ``localnode.linefreq`` attribute.

        **Description:**
            - This attribute contains the power line frequency setting that is used for NPLC
              calculations.

        **Usage:**
            - Accessing this property will send the ``print(localnode.linefreq)`` query.
            - Setting this property to a value will send the ``localnode.linefreq = value`` command.

        **TSP Syntax:**

        ::

            - localnode.linefreq = value
            - print(localnode.linefreq)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".linefreq", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.linefreq = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.linefreq`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def model(self) -> str:
        """Access the ``localnode.model`` attribute.

        **Description:**
            - This attribute stores the model number.

        **Usage:**
            - Accessing this property will send the ``print(localnode.model)`` query.

        **TSP Syntax:**

        ::

            - print(localnode.model)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".model"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.model)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.model`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def password(self) -> str:
        """Access the ``localnode.password`` attribute.

        **Description:**
            - This attribute stores the remote access password.

        **Usage:**
            - Setting this property to a value will send the ``localnode.password = value`` command.

        **TSP Syntax:**

        ::

            - localnode.password = value

        Raises:
            AttributeError: Indicates that this attribute is write-only.
        """
        if self._device.command_syntax_enabled:  # type: ignore[union-attr]
            return self._cmd_syntax + ".password"
        msg = f"``{self._cmd_syntax}.password`` is a write-only attribute."
        raise AttributeError(msg)

    @password.setter
    def password(self, value: Union[str, float]) -> None:
        """Access the ``localnode.password`` attribute.

        **Description:**
            - This attribute stores the remote access password.

        **Usage:**
            - Setting this property to a value will send the ``localnode.password = value`` command.

        **TSP Syntax:**

        ::

            - localnode.password = value

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.password = {value}")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.password`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def passwordmode(self) -> str:
        """Access the ``localnode.passwordmode`` attribute.

        **Description:**
            - This attribute stores the password enable mode for remote access to the instrument.

        **Usage:**
            - Accessing this property will send the ``print(localnode.passwordmode)`` query.
            - Setting this property to a value will send the ``localnode.passwordmode = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.passwordmode = value
            - print(localnode.passwordmode)

        **Info:**
            - ``mode``, the remote password enable mode.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".passwordmode"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.passwordmode)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.passwordmode`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @passwordmode.setter
    def passwordmode(self, value: Union[str, float]) -> None:
        """Access the ``localnode.passwordmode`` attribute.

        **Description:**
            - This attribute stores the password enable mode for remote access to the instrument.

        **Usage:**
            - Accessing this property will send the ``print(localnode.passwordmode)`` query.
            - Setting this property to a value will send the ``localnode.passwordmode = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.passwordmode = value
            - print(localnode.passwordmode)

        **Info:**
            - ``mode``, the remote password enable mode.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".passwordmode", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.passwordmode = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.passwordmode`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def prompts(self) -> str:
        """Access the ``localnode.prompts`` attribute.

        **Description:**
            - This attribute determines if the instrument generates prompts in response to command
              messages.

        **Usage:**
            - Accessing this property will send the ``print(localnode.prompts)`` query.
            - Setting this property to a value will send the ``localnode.prompts = value`` command.

        **TSP Syntax:**

        ::

            - localnode.prompts = value
            - print(localnode.prompts)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".prompts"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.prompts)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.prompts`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @prompts.setter
    def prompts(self, value: Union[str, float]) -> None:
        """Access the ``localnode.prompts`` attribute.

        **Description:**
            - This attribute determines if the instrument generates prompts in response to command
              messages.

        **Usage:**
            - Accessing this property will send the ``print(localnode.prompts)`` query.
            - Setting this property to a value will send the ``localnode.prompts = value`` command.

        **TSP Syntax:**

        ::

            - localnode.prompts = value
            - print(localnode.prompts)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".prompts", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.prompts = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.prompts`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def prompts4882(self) -> str:
        """Access the ``localnode.prompts4882`` attribute.

        **Description:**
            - This attribute enables and disables the generation of prompts for IEEE Std 488.2
              common commands.

        **Usage:**
            - Accessing this property will send the ``print(localnode.prompts4882)`` query.
            - Setting this property to a value will send the ``localnode.prompts4882 = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.prompts4882 = value
            - print(localnode.prompts4882)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".prompts4882"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.prompts4882)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.prompts4882`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @prompts4882.setter
    def prompts4882(self, value: Union[str, float]) -> None:
        """Access the ``localnode.prompts4882`` attribute.

        **Description:**
            - This attribute enables and disables the generation of prompts for IEEE Std 488.2
              common commands.

        **Usage:**
            - Accessing this property will send the ``print(localnode.prompts4882)`` query.
            - Setting this property to a value will send the ``localnode.prompts4882 = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.prompts4882 = value
            - print(localnode.prompts4882)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".prompts4882", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.prompts4882 = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.prompts4882`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def revision(self) -> str:
        """Access the ``localnode.revision`` attribute.

        **Description:**
            - This attribute stores the firmware revision level.

        **Usage:**
            - Accessing this property will send the ``print(localnode.revision)`` query.

        **TSP Syntax:**

        ::

            - print(localnode.revision)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".revision"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.revision)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.revision`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def serialno(self) -> str:
        """Access the ``localnode.serialno`` attribute.

        **Description:**
            - This attribute stores the serial number of the instrument.

        **Usage:**
            - Accessing this property will send the ``print(localnode.serialno)`` query.

        **TSP Syntax:**

        ::

            - print(localnode.serialno)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".serialno"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.serialno)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.serialno`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def showerrors(self) -> str:
        """Access the ``localnode.showerrors`` attribute.

        **Description:**
            - This attribute sets whether or not the instrument automatically sends generated
              errors.

        **Usage:**
            - Accessing this property will send the ``print(localnode.showerrors)`` query.
            - Setting this property to a value will send the ``localnode.showerrors = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.showerrors = value
            - print(localnode.showerrors)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".showerrors"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.showerrors)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.showerrors`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @showerrors.setter
    def showerrors(self, value: Union[str, float]) -> None:
        """Access the ``localnode.showerrors`` attribute.

        **Description:**
            - This attribute sets whether or not the instrument automatically sends generated
              errors.

        **Usage:**
            - Accessing this property will send the ``print(localnode.showerrors)`` query.
            - Setting this property to a value will send the ``localnode.showerrors = value``
              command.

        **TSP Syntax:**

        ::

            - localnode.showerrors = value
            - print(localnode.showerrors)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".showerrors", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.showerrors = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.showerrors`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def reset(self) -> None:
        """Run the ``localnode.reset()`` function.

        **Description:**
            - This function resets the local node instrument.

        **TSP Syntax:**

        ::

            - localnode.reset()

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.reset()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.reset()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



"""The time commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - TIMe <QString>
    - TIMe?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Time(SCPICmdWrite, SCPICmdRead):
    """The ``TIMe`` command.

    **Description:**
        - This command sets the time in the form ``hh:mm:ss`` where hh refers to a two-digit hour
          number, mm refers to a two-digit minute number from 01 to 60, and ss refers to a two-digit
          second number from 01 to 60.

    **Usage:**
        - Using the ``.query()`` method will send the ``TIMe?`` query.
        - Using the ``.verify(value)`` method will send the ``TIMe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``TIMe value`` command.

    **SCPI Syntax:**

    ::

        - TIMe <QString>
        - TIMe?

    **Info:**
        - ``<QString>`` is a quoted string representing the desired time.
    """

    _WRAP_ARG_WITH_QUOTES = True

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "TIMe") -> None:
        super().__init__(device, cmd_syntax)



"""The bwaveform commands module.

These commands are used in the following models:
AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - BWAVeform:AMPLitude <amplitude>
    - BWAVeform:AUTO {length|cycle|duration|freqency|sample rate}
    - BWAVeform:AUTO?
    - BWAVeform:COMPile
    - BWAVeform:COMPile:CASSign {0|1|OFF|ON}
    - BWAVeform:COMPile:CASSign?
    - BWAVeform:COMPile:CHANnel {NONE|<channel_number>}
    - BWAVeform:COMPile:NAME <waveform_name>
    - BWAVeform:COMPile:NAME?
    - BWAVeform:COMPile:PLAY {0|1|OFF|ON}
    - BWAVeform:COMPile:PLAY?
    - BWAVeform:CYCLe <cycle>
    - BWAVeform:FDRange {OFF|ON|0|1}
    - BWAVeform:FREQuency <frequency>
    - BWAVeform:FUNCtion {sine|square|triangle|ramp|noise|DC}
    - BWAVeform:FUNCtion?
    - BWAVeform:HIGH <high>
    - BWAVeform:LENGth <length>
    - BWAVeform:LOW <low>
    - BWAVeform:OFFSet <offset>
    - BWAVeform:RESet
    - BWAVeform:SRATe <sample_rate>
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class BwaveformSrate(SCPICmdWrite):
    """The ``BWAVeform:SRATe`` command.

    **Description:**
        - This command sets or returns the Sample Rate for the waveform created by the Basic
          Waveform editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:SRATe value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:SRATe <sample_rate>
    """


class BwaveformReset(SCPICmdWriteNoArguments):
    """The ``BWAVeform:RESet`` command.

    **Description:**
        - This command resets the Basic Waveform editor plug-in to its default values.

    **Usage:**
        - Using the ``.write()`` method will send the ``BWAVeform:RESet`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:RESet
    """


class BwaveformOffset(SCPICmdWrite):
    """The ``BWAVeform:OFFSet`` command.

    **Description:**
        - This command sets or returns the Offset voltage value for the waveform created by the
          Basic Waveform editor plug-in. This setting can be affected if the system is set to use
          the full DAC range. Using the full DAC range is the default setting. Refer to the command
          ``BWAVEFORM:FDRANGE`` for more information.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:OFFSet value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:OFFSet <offset>
    """


class BwaveformLow(SCPICmdWrite):
    """The ``BWAVeform:LOW`` command.

    **Description:**
        - This command sets or returns the Low voltage value for the waveform created by the Basic
          Waveform editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:LOW value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:LOW <low>
    """


class BwaveformLength(SCPICmdWrite):
    """The ``BWAVeform:LENGth`` command.

    **Description:**
        - This command sets or returns the Length for the waveform created by the Basic Waveform
          editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:LENGth value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:LENGth <length>
    """


class BwaveformHigh(SCPICmdWrite):
    """The ``BWAVeform:HIGH`` command.

    **Description:**
        - This command sets or returns the High voltage value for the waveform created by the Basic
          Waveform editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:HIGH value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:HIGH <high>
    """


class BwaveformFunction(SCPICmdWrite, SCPICmdRead):
    """The ``BWAVeform:FUNCtion`` command.

    **Description:**
        - This command sets or returns the Basic Waveform editor plug-in waveform type.

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform:FUNCtion?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform:FUNCtion?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``BWAVeform:FUNCtion value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:FUNCtion {sine|square|triangle|ramp|noise|DC}
        - BWAVeform:FUNCtion?

    **Info:**
        - ``*RST`` sets this to SINE.
    """


class BwaveformFrequency(SCPICmdWrite):
    """The ``BWAVeform:FREQuency`` command.

    **Description:**
        - This command sets or returns the Frequency for the waveform created by the Basic Waveform
          editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:FREQuency value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:FREQuency <frequency>
    """


class BwaveformFdrange(SCPICmdWrite):
    """The ``BWAVeform:FDRange`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of the Basic Waveform editor
          plug-in to use or not use the full DAC range during compile. Using the full DAC range when
          compiling waveforms results in waveforms with the best resolution. When enabled, if the
          selected offset and amplitude are within the range of the instrument's hardware, then the
          compiled waveform is compiled using the full DAC range and the compiled waveform's
          recommended amplitude and offset properties are set to the requested amplitude and offset
          values. If the selected offset and amplitude will result in a compiled waveform that does
          not take advantage of the full DAC range, the instrument adjusts the compiled waveform's
          recommended amplitude and offset values to use the full DAC range. If the system cannot
          achieve the full DAC range, a warning message is displayed. When disabled, the waveform is
          compiled using the specified amplitude and offset values and the compiled waveform's
          recommended amplitude is set to the maximum value and the recommended offset is set to 0.
          The control is not available for a DC waveform.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:FDRange value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:FDRange {OFF|ON|0|1}
    """


class BwaveformCycle(SCPICmdWrite):
    """The ``BWAVeform:CYCLe`` command.

    **Description:**
        - This command sets or returns the Cycle value (number of times the waveform repeats) for
          the waveform created by the Basic Waveform editor plug-in.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:CYCLe value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:CYCLe <cycle>
    """


class BwaveformCompilePlay(SCPICmdWrite, SCPICmdRead):
    """The ``BWAVeform:COMPile:PLAY`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of the Basic Waveform editor
          to either immediately play the waveform after compile or just compile.

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform:COMPile:PLAY?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:PLAY?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:PLAY value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:COMPile:PLAY {0|1|OFF|ON}
        - BWAVeform:COMPile:PLAY?
    """


class BwaveformCompileName(SCPICmdWrite, SCPICmdRead):
    """The ``BWAVeform:COMPile:NAME`` command.

    **Description:**
        - This command sets or returns the name of the Basic Waveform editor plug-in compiled
          waveform. If the name already exists in the Waveform List, the name is appended with an
          underscore suffix such as '``Waveform_1``'.

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform:COMPile:NAME?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:NAME?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:NAME value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:COMPile:NAME <waveform_name>
        - BWAVeform:COMPile:NAME?
    """


class BwaveformCompileChannel(SCPICmdWrite):
    """The ``BWAVeform:COMPile:CHANnel`` command.

    **Description:**
        - This command sets or returns the playout channel intended for the compiled waveform of the
          Basic Waveform editor plug-in. The selected channel is also used to define the amplitude
          and offset range.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:CHANnel value``
          command.

    **SCPI Syntax:**

    ::

        - BWAVeform:COMPile:CHANnel {NONE|<channel_number>}
    """


class BwaveformCompileCassign(SCPICmdWrite, SCPICmdRead):
    """The ``BWAVeform:COMPile:CASSign`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of the Basic Waveform editor
          to compile the waveform and immediately assign it to a specified channel (enabled) or just
          compile the waveform (disabled).

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform:COMPile:CASSign?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:CASSign?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:CASSign value``
          command.

    **SCPI Syntax:**

    ::

        - BWAVeform:COMPile:CASSign {0|1|OFF|ON}
        - BWAVeform:COMPile:CASSign?
    """


class BwaveformCompile(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``BWAVeform:COMPile`` command.

    **Description:**
        - This command initiates the Basic Waveform editor plug-in compile process. The created
          waveform is placed in the Waveform List.

    **Usage:**
        - Using the ``.write()`` method will send the ``BWAVeform:COMPile`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:COMPile

    Properties:
        - ``.cassign``: The ``BWAVeform:COMPile:CASSign`` command.
        - ``.channel``: The ``BWAVeform:COMPile:CHANnel`` command.
        - ``.name``: The ``BWAVeform:COMPile:NAME`` command.
        - ``.play``: The ``BWAVeform:COMPile:PLAY`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._cassign = BwaveformCompileCassign(device, f"{self._cmd_syntax}:CASSign")
        self._channel = BwaveformCompileChannel(device, f"{self._cmd_syntax}:CHANnel")
        self._name = BwaveformCompileName(device, f"{self._cmd_syntax}:NAME")
        self._play = BwaveformCompilePlay(device, f"{self._cmd_syntax}:PLAY")

    @property
    def cassign(self) -> BwaveformCompileCassign:
        """Return the ``BWAVeform:COMPile:CASSign`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of the Basic Waveform
              editor to compile the waveform and immediately assign it to a specified channel
              (enabled) or just compile the waveform (disabled).

        **Usage:**
            - Using the ``.query()`` method will send the ``BWAVeform:COMPile:CASSign?`` query.
            - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:CASSign?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:CASSign value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:COMPile:CASSign {0|1|OFF|ON}
            - BWAVeform:COMPile:CASSign?
        """
        return self._cassign

    @property
    def channel(self) -> BwaveformCompileChannel:
        """Return the ``BWAVeform:COMPile:CHANnel`` command.

        **Description:**
            - This command sets or returns the playout channel intended for the compiled waveform of
              the Basic Waveform editor plug-in. The selected channel is also used to define the
              amplitude and offset range.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:CHANnel value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:COMPile:CHANnel {NONE|<channel_number>}
        """
        return self._channel

    @property
    def name(self) -> BwaveformCompileName:
        """Return the ``BWAVeform:COMPile:NAME`` command.

        **Description:**
            - This command sets or returns the name of the Basic Waveform editor plug-in compiled
              waveform. If the name already exists in the Waveform List, the name is appended with
              an underscore suffix such as '``Waveform_1``'.

        **Usage:**
            - Using the ``.query()`` method will send the ``BWAVeform:COMPile:NAME?`` query.
            - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:NAME?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:NAME value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:COMPile:NAME <waveform_name>
            - BWAVeform:COMPile:NAME?
        """
        return self._name

    @property
    def play(self) -> BwaveformCompilePlay:
        """Return the ``BWAVeform:COMPile:PLAY`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of the Basic Waveform
              editor to either immediately play the waveform after compile or just compile.

        **Usage:**
            - Using the ``.query()`` method will send the ``BWAVeform:COMPile:PLAY?`` query.
            - Using the ``.verify(value)`` method will send the ``BWAVeform:COMPile:PLAY?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``BWAVeform:COMPile:PLAY value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:COMPile:PLAY {0|1|OFF|ON}
            - BWAVeform:COMPile:PLAY?
        """
        return self._play


class BwaveformAuto(SCPICmdWrite, SCPICmdRead):
    """The ``BWAVeform:AUTO`` command.

    **Description:**
        - This command sets or returns the Basic Waveform editor plug-in Auto Calculate setting,
          determining which value is automatically calculated.

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform:AUTO?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform:AUTO?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``BWAVeform:AUTO value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:AUTO {length|cycle|duration|freqency|sample rate}
        - BWAVeform:AUTO?

    **Info:**
        - ``*RST`` sets this to Cycle.
    """


class BwaveformAmplitude(SCPICmdWrite):
    """The ``BWAVeform:AMPLitude`` command.

    **Description:**
        - This command sets or returns the peak-to-peak Amplitude value for the waveform created by
          the Basic Waveform editor plug-in. This setting can be affected if the system is set to
          use the full DAC range. Using the full DAC range is the default setting. Refer to the
          command ``BWAVEFORM:FDRANGE`` for more information.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``BWAVeform:AMPLitude value`` command.

    **SCPI Syntax:**

    ::

        - BWAVeform:AMPLitude <amplitude>
    """


#  pylint: disable=too-many-instance-attributes
class Bwaveform(SCPICmdRead):
    """The ``BWAVeform`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``BWAVeform?`` query.
        - Using the ``.verify(value)`` method will send the ``BWAVeform?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.amplitude``: The ``BWAVeform:AMPLitude`` command.
        - ``.auto``: The ``BWAVeform:AUTO`` command.
        - ``.compile``: The ``BWAVeform:COMPile`` command.
        - ``.cycle``: The ``BWAVeform:CYCLe`` command.
        - ``.fdrange``: The ``BWAVeform:FDRange`` command.
        - ``.frequency``: The ``BWAVeform:FREQuency`` command.
        - ``.function``: The ``BWAVeform:FUNCtion`` command.
        - ``.high``: The ``BWAVeform:HIGH`` command.
        - ``.length``: The ``BWAVeform:LENGth`` command.
        - ``.low``: The ``BWAVeform:LOW`` command.
        - ``.offset``: The ``BWAVeform:OFFSet`` command.
        - ``.reset``: The ``BWAVeform:RESet`` command.
        - ``.srate``: The ``BWAVeform:SRATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "BWAVeform") -> None:
        super().__init__(device, cmd_syntax)
        self._amplitude = BwaveformAmplitude(device, f"{self._cmd_syntax}:AMPLitude")
        self._auto = BwaveformAuto(device, f"{self._cmd_syntax}:AUTO")
        self._compile = BwaveformCompile(device, f"{self._cmd_syntax}:COMPile")
        self._cycle = BwaveformCycle(device, f"{self._cmd_syntax}:CYCLe")
        self._fdrange = BwaveformFdrange(device, f"{self._cmd_syntax}:FDRange")
        self._frequency = BwaveformFrequency(device, f"{self._cmd_syntax}:FREQuency")
        self._function = BwaveformFunction(device, f"{self._cmd_syntax}:FUNCtion")
        self._high = BwaveformHigh(device, f"{self._cmd_syntax}:HIGH")
        self._length = BwaveformLength(device, f"{self._cmd_syntax}:LENGth")
        self._low = BwaveformLow(device, f"{self._cmd_syntax}:LOW")
        self._offset = BwaveformOffset(device, f"{self._cmd_syntax}:OFFSet")
        self._reset = BwaveformReset(device, f"{self._cmd_syntax}:RESet")
        self._srate = BwaveformSrate(device, f"{self._cmd_syntax}:SRATe")

    @property
    def amplitude(self) -> BwaveformAmplitude:
        """Return the ``BWAVeform:AMPLitude`` command.

        **Description:**
            - This command sets or returns the peak-to-peak Amplitude value for the waveform created
              by the Basic Waveform editor plug-in. This setting can be affected if the system is
              set to use the full DAC range. Using the full DAC range is the default setting. Refer
              to the command ``BWAVEFORM:FDRANGE`` for more information.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:AMPLitude value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:AMPLitude <amplitude>
        """
        return self._amplitude

    @property
    def auto(self) -> BwaveformAuto:
        """Return the ``BWAVeform:AUTO`` command.

        **Description:**
            - This command sets or returns the Basic Waveform editor plug-in Auto Calculate setting,
              determining which value is automatically calculated.

        **Usage:**
            - Using the ``.query()`` method will send the ``BWAVeform:AUTO?`` query.
            - Using the ``.verify(value)`` method will send the ``BWAVeform:AUTO?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``BWAVeform:AUTO value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:AUTO {length|cycle|duration|freqency|sample rate}
            - BWAVeform:AUTO?

        **Info:**
            - ``*RST`` sets this to Cycle.
        """
        return self._auto

    @property
    def compile(self) -> BwaveformCompile:
        """Return the ``BWAVeform:COMPile`` command.

        **Description:**
            - This command initiates the Basic Waveform editor plug-in compile process. The created
              waveform is placed in the Waveform List.

        **Usage:**
            - Using the ``.write()`` method will send the ``BWAVeform:COMPile`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:COMPile

        Sub-properties:
            - ``.cassign``: The ``BWAVeform:COMPile:CASSign`` command.
            - ``.channel``: The ``BWAVeform:COMPile:CHANnel`` command.
            - ``.name``: The ``BWAVeform:COMPile:NAME`` command.
            - ``.play``: The ``BWAVeform:COMPile:PLAY`` command.
        """
        return self._compile

    @property
    def cycle(self) -> BwaveformCycle:
        """Return the ``BWAVeform:CYCLe`` command.

        **Description:**
            - This command sets or returns the Cycle value (number of times the waveform repeats)
              for the waveform created by the Basic Waveform editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:CYCLe value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:CYCLe <cycle>
        """
        return self._cycle

    @property
    def fdrange(self) -> BwaveformFdrange:
        """Return the ``BWAVeform:FDRange`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of the Basic Waveform
              editor plug-in to use or not use the full DAC range during compile. Using the full DAC
              range when compiling waveforms results in waveforms with the best resolution. When
              enabled, if the selected offset and amplitude are within the range of the instrument's
              hardware, then the compiled waveform is compiled using the full DAC range and the
              compiled waveform's recommended amplitude and offset properties are set to the
              requested amplitude and offset values. If the selected offset and amplitude will
              result in a compiled waveform that does not take advantage of the full DAC range, the
              instrument adjusts the compiled waveform's recommended amplitude and offset values to
              use the full DAC range. If the system cannot achieve the full DAC range, a warning
              message is displayed. When disabled, the waveform is compiled using the specified
              amplitude and offset values and the compiled waveform's recommended amplitude is set
              to the maximum value and the recommended offset is set to 0. The control is not
              available for a DC waveform.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:FDRange value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:FDRange {OFF|ON|0|1}
        """
        return self._fdrange

    @property
    def frequency(self) -> BwaveformFrequency:
        """Return the ``BWAVeform:FREQuency`` command.

        **Description:**
            - This command sets or returns the Frequency for the waveform created by the Basic
              Waveform editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:FREQuency value``
              command.

        **SCPI Syntax:**

        ::

            - BWAVeform:FREQuency <frequency>
        """
        return self._frequency

    @property
    def function(self) -> BwaveformFunction:
        """Return the ``BWAVeform:FUNCtion`` command.

        **Description:**
            - This command sets or returns the Basic Waveform editor plug-in waveform type.

        **Usage:**
            - Using the ``.query()`` method will send the ``BWAVeform:FUNCtion?`` query.
            - Using the ``.verify(value)`` method will send the ``BWAVeform:FUNCtion?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``BWAVeform:FUNCtion value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:FUNCtion {sine|square|triangle|ramp|noise|DC}
            - BWAVeform:FUNCtion?

        **Info:**
            - ``*RST`` sets this to SINE.
        """
        return self._function

    @property
    def high(self) -> BwaveformHigh:
        """Return the ``BWAVeform:HIGH`` command.

        **Description:**
            - This command sets or returns the High voltage value for the waveform created by the
              Basic Waveform editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:HIGH value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:HIGH <high>
        """
        return self._high

    @property
    def length(self) -> BwaveformLength:
        """Return the ``BWAVeform:LENGth`` command.

        **Description:**
            - This command sets or returns the Length for the waveform created by the Basic Waveform
              editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:LENGth value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:LENGth <length>
        """
        return self._length

    @property
    def low(self) -> BwaveformLow:
        """Return the ``BWAVeform:LOW`` command.

        **Description:**
            - This command sets or returns the Low voltage value for the waveform created by the
              Basic Waveform editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:LOW value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:LOW <low>
        """
        return self._low

    @property
    def offset(self) -> BwaveformOffset:
        """Return the ``BWAVeform:OFFSet`` command.

        **Description:**
            - This command sets or returns the Offset voltage value for the waveform created by the
              Basic Waveform editor plug-in. This setting can be affected if the system is set to
              use the full DAC range. Using the full DAC range is the default setting. Refer to the
              command ``BWAVEFORM:FDRANGE`` for more information.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:OFFSet value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:OFFSet <offset>
        """
        return self._offset

    @property
    def reset(self) -> BwaveformReset:
        """Return the ``BWAVeform:RESet`` command.

        **Description:**
            - This command resets the Basic Waveform editor plug-in to its default values.

        **Usage:**
            - Using the ``.write()`` method will send the ``BWAVeform:RESet`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:RESet
        """
        return self._reset

    @property
    def srate(self) -> BwaveformSrate:
        """Return the ``BWAVeform:SRATe`` command.

        **Description:**
            - This command sets or returns the Sample Rate for the waveform created by the Basic
              Waveform editor plug-in.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``BWAVeform:SRATe value`` command.

        **SCPI Syntax:**

        ::

            - BWAVeform:SRATe <sample_rate>
        """
        return self._srate



"""The curvestream commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, MSO5KB, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CURVEStream {<Block>|<asc curve>}
    - CURVEStream?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Curvestream(SCPICmdWrite, SCPICmdRead):
    """The ``CURVEStream`` command.

    **Description:**
        - This query continuously transfers waveform data from the instrument as it is acquired.
          This command puts the instrument into a talk-only mode, allowing the controller to receive
          waveform records as fast as (and as soon as) they are acquired. Use the ``DATA:SOURCE``
          command to specify the waveform sources. The command does the same thing as the CURVE
          command. Control of the instrument through the user interface or other external client is
          not possible while in streaming mode. The GPIB controller must take the instrument out of
          this continuous talking mode to terminate the query and allow other input sources to
          resume communication with the instrument. The following options are available to
          transition out of streaming curve mode: send a device clear over the bus or send another
          query to the instrument (a MEPE Query Interrupted error will occur, but the instrument
          will be placed back into its normal talk/listen mode). Turning the waveform screen display
          mode off (``:DISPLAY:WAVEFORM OFF``) will increase waveform throughput during streaming
          mode. While in streaming mode, two extreme conditions can occur. If the waveform records
          are being acquired slowly (high resolution), configure the controller for long time-out
          thresholds, as the data is not sent out until each complete record is acquired. If the
          waveform records are being acquired rapidly (low resolution), and the controller is not
          reading the data off the bus fast enough, the trigger rate is slowed to allow each
          waveform to be sent sequentially.

    **Usage:**
        - Using the ``.query()`` method will send the ``CURVEStream?`` query.
        - Using the ``.verify(value)`` method will send the ``CURVEStream?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CURVEStream value`` command.

    **SCPI Syntax:**

    ::

        - CURVEStream {<Block>|<asc curve>}
        - CURVEStream?
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CURVEStream"
    ) -> None:
        super().__init__(device, cmd_syntax)



"""The factory commands module.

These commands are used in the following models:
DPO2K, DPO2KB, DPO4K, DPO4KB, DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC,
DSA70KD, LPD6, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO2, MSO2K, MSO2KB, MSO4, MSO4K, MSO4KB, MSO5,
MSO5B, MSO5KB, MSO5LP, MSO6, MSO6B, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - FACtory
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Factory(SCPICmdWriteNoArguments):
    """The ``FACtory`` command.

    **Description:**
        - This command (no query form) resets the instrument to its factory default settings. This
          command is equivalent to pressing the DEFAULT SETUP button located on the instrument front
          panel or selecting Default Setup from the File menu. This command Performs the following
          in addition to what is done for the ``*RST`` command: Clears any pending OPC operations.
          Resets the following IEEE488.2 registers: ``*ESE 0`` (Event Status Enable Register)
          ``*SRE 0`` (Service Request Enable Register) DESE 255 (Device Event Status Enable
          Register) ``*PSC 1`` (Power-on Status Clear Flag) Deletes all defined aliases. Enables
          command headers (``:HEADer 1``).

    **Usage:**
        - Using the ``.write()`` method will send the ``FACtory`` command.

    **SCPI Syntax:**

    ::

        - FACtory
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "FACtory") -> None:
        super().__init__(device, cmd_syntax)
